==> vpn-user-portal-3.5.6.tgz: vpn-user-portal/locale/pt-PT.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => 'Ligações em intervalos de 5 minutos',
    //'#Unique Guest Users' => '',
    '#Unique Users' => 'Utilizadores Únicos',
    '#Unique users and max #connections per day' => 'Utilizadores únicos e # máximo de ligações por dia',
    'ACL Permission List' => 'Lista de Acesso ACL',
    'Account' => 'Conta',
    'Active' => 'Ativo',
    'Active Configurations' => 'Configurações Ativas',
    'Aggregated' => 'Agregado',
    'All' => 'Todos',
    'An application attempts to establish a VPN connection.' => 'Uma aplicação está a tentar estabelecer uma ligação VPN.',
    'An error occurred.' => 'Ocorreu um erro.',
    'Application Usage' => 'Uso da Aplicação',
    'Approve' => 'Aprove',
    'Approve Application' => 'Aprove Aplicação',
    //'Authentication Data' => '',
    'Authorized Applications' => 'Aplicações Autorizadas',
    'Authorized On' => 'Autorizada em',
    'Available Profiles' => 'Perfis Disponíveis',
    'Block LAN' => 'Bloquear LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'Utilização da CPU',
    'Change Password' => 'Altere Palavra-passe',
    'Configurations' => 'Configurações',
    'Confirm' => 'Confirme',
    'Connected' => 'Ligado',
    'Connections' => 'Ligações',
    'Created On' => 'Criado em',
    'Current Password' => 'Palavra-passe atual',
    'Current Password not correct!' => 'Palavra-passe atual incorreta!',
    'Currently there are no clients connected to this profile.' => 'De momento não há clientes ligados a este perfil.',
    'DNS Search Domain(s)' => 'Domínio(s) de Pesquisa DNS',
    'DNS Server(s)' => 'Servidores DNS',
    'Danger Zone' => 'Zona de Perigo',
    'Date/Time' => 'Data/Hora',
    'Default Gateway' => 'Gateway Padrão',
    'Delete' => 'Apague',
    'Delete Account' => 'Apague Conta',
    'Delete Account Data' => 'Apague Dados de Conta',
    'Disable Account' => 'Desative Conta',
    'Disabled' => 'Desativado',
    'Disconnected' => 'Desligado',
    'Distribution of unique users over the VPN applications.' => 'Distribuição de utilizadores únicos pelas aplicações VPN',
    'Download' => 'Descarregar',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Não é permitido descarregar configurações VPN. Por favor utilize a aplicação VPN',
    'Enable Account' => 'Ative Conta',
    'Error' => 'Erro',
    'Excluded Route(s)' => 'Rota(s) Excluída(s)',
    'Expires On' => 'Expira em',
    'Export (CSV)' => 'Exporte (CSV)',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Encontre o identificador do utilizador que usou um endereço IPv4 ou IPv6 num determinado momento.',
    'Fingerprint' => 'Impressão Digital',
    'Here you can change the password for your account.' => 'Aqui pode mudar a palavra-passe da sua conta.',
    'Home' => 'Início',
    'Hostname' => 'Nome de Host',
    'IP Address' => 'Endereço IP',
    'IPs' => 'IPs',
    'IPv4 Prefix' => 'Prefixo IPv4',
    'IPv6 Prefix' => 'Prefixo IPv6',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importe ou copie/cole esta configuração para a sua aplicação WireGuard',
    'Info' => 'Informações',
    'Issues' => 'Problemas',
    'Live' => 'Direto',
    'Log' => 'Log',
    //'MTU' => '',
    'Max #Connections' => '# Máximo de Ligações',
    'More' => 'Mais',
    'N/A' => 'N/A',
    'Name' => 'Nome',
    'New Configuration' => 'Nova Configuração',
    'New Password' => 'Nova Palavra-passe',
    'New Password (confirm)' => 'Nova Palavra-passe (confirme)',
    'New Password and New Password (confirm) MUST match!' => 'Nova Palavra-passe e Nova Palavra-passe (confirme) TÊM de ser iguais!',
    'No Permission(s)' => 'Sem Acesso(s)',
    'No VPN profiles are available for your account.' => 'Não existem perfis VPN disponíveis para a sua conta.',
    'Node URL' => 'Nó de URL',
    'Node(s)' => 'Nó(s)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Obtenha um novo ficheiro de configuração VPN para utilização no seu cliente de VPN.',
    'Offered Ports' => 'Portas Disponíveis',
    'Offline' => 'Desligado',
    'Online' => 'Online',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Aprove apenas se estiver a tentar estabelecer uma ligação VPN com esta aplicação.',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'Registo de OpenVPN no Servidor',
    'Password' => 'Palavra-passe',
    'Permissions' => 'Acessos',
    'Please sign in with your username and password.' => 'Por favor autentique-se com o seu nome de utilizador e palavra-passe.',
    'Port' => 'Porta',
    'Ports' => 'Portas',
    'Preferred Protocol' => 'Protocolo Preferido',
    'Profile' => 'Perfil',
    //'Profile ID' => '',
    'Profile Usage' => 'Utilização de Perfil',
    'Profile(s)' => 'Perfil(is)',
    'Public Key' => 'Chave Pública',
    //'Refresh' => '',
    'Results' => 'Resultados',
    'Revoke' => 'Revogar',
    'Route(s)' => 'Rota(s)',
    'Search' => 'Procurar',
    'Select a profile and choose a name, e.g. "Phone".' => 'Selecione um perfil e escolha um nome, como, por exemplo, "Telemóvel".',
    'Server' => 'Servidor',
    'Sign In' => 'Entrar',
    'Sign Out' => 'Sair',
    'Stats' => 'Estatísticas',
    'The <em>Date/Time</em> MUST be in UTC.' => 'A <em>Data/Hora</em>    tem de ser em UTC',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'O campo <em>Data/Hora</em> aceita datas com o formato <code>Y-m-d H:m:s</code>, p.ex. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'As credenciais que forneceu não estavam corretas',
    'The list of applications you authorized to create a VPN connection.' => 'A lista de aplicações que autorizou a criar ligações VPN.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'O número máximo de clientes VPN ligados simultaneamente num determinado momento durante a semana passada',
    'The most recent VPN connections with this account.' => 'As ligações VPN mais recentes com esta conta.',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => 'O número de utilizadores únicos ligados ao serviço VPN na semana passada',
    'The table below shows the per profile VPN usage over the last week.' => 'A tabela abaixo mostra a utilização de VPN por perfil durante a semana passada',
    'There are no results matching your criteria.' => 'Não há resultados que satisfaçam os seus critérios',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Este servidor usa uma fonte de autenticação externa. Apagar os dados de conta não impede que o utilizador se autentique (novamente)!',
    'This user does not have any active configurations.' => 'Este utilizador não tem nenhumas configurações ativas.',
    'This user does not have any connections.' => 'Este utilizador não tem nenhumas ligações.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Para impedir que aplicações maliciosas estabeleçam secretamente uma ligação VPN em seu nome, tem de aprovar explicitamente esta aplicação.',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Use a aplicação WireGuard no seu dispositivo móvel para ler este código QR',
    'User ID' => 'ID de Utilizador',
    'Username' => 'Nome de Utilizador',
    'Users' => 'Utilizadores',
    'VPN Portal' => 'Portal VPN',
    'Version' => 'Versão',
    'Welcome to this VPN service!' => 'Bem-vindo a este serviço VPN!',
    'Why is this necessary?' => 'Porque que é que isto é necessário?',
    'WireGuard' => 'WireGuard',
    'WireGuard Configuration' => 'Configuração de WireGuard',
    'You can download the detailed VPN usage statistics below.' => 'Pode descarregar as estatísticas detalhadas de utilização da VPN abaixo.',
    'You cannot manage your own user account.' => 'Não pode gerir a sua própria conta de utilizador.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Atingiu o número máximo de configurações de VPN ativas permitidas. Apague algumas primeiro.',
    'Your account does not have access to any VPN profile.' => 'A sua conta não tem acesso a nenhum perfil de VPN.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'A sua nova configuração expira em %expiryDate%. Volte aqui para criar uma nova configuração após esta expirar!',
];

==> vpn-user-portal-3.9.4.tgz: vpn-user-portal/locale/pt-PT.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => 'Ligações em intervalos de 5 minutos',
    //'#Unique Guest Users' => '',
    '#Unique Users' => 'Utilizadores Únicos',
    '#Unique users and max #connections per day' => 'Utilizadores únicos e # máximo de ligações por dia',
    'ACL Permission List' => 'Lista de Acesso ACL',
    'Account' => 'Conta',
    'Active' => 'Ativo',
    'Active Configurations' => 'Configurações Ativas',
    //'Additional Credential' => '',
    'Aggregated' => 'Agregado',
    'All' => 'Todos',
    'An application attempts to establish a VPN connection.' => 'Uma aplicação está a tentar estabelecer uma ligação VPN.',
    'An error occurred.' => 'Ocorreu um erro.',
    'Application Usage' => 'Uso da Aplicação',
    'Approve' => 'Aprove',
    'Approve Application' => 'Aprove Aplicação',
    //'Authentication Data' => '',
    'Authorized Applications' => 'Aplicações Autorizadas',
    'Authorized On' => 'Autorizada em',
    'Available Profiles' => 'Perfis Disponíveis',
    'Block LAN' => 'Bloquear LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'Utilização da CPU',
    'Change Password' => 'Altere Palavra-passe',
    'Configurations' => 'Configurações',
    'Confirm' => 'Confirme',
    'Connected' => 'Ligado',
    'Connections' => 'Ligações',
    'Created On' => 'Criado em',
    'Current Password' => 'Palavra-passe atual',
    'Current Password not correct!' => 'Palavra-passe atual incorreta!',
    'Currently there are no clients connected to this profile.' => 'De momento não há clientes ligados a este perfil.',
    'DNS Search Domain(s)' => 'Domínio(s) de Pesquisa DNS',
    'DNS Server(s)' => 'Servidores DNS',
    'Danger Zone' => 'Zona de Perigo',
    //'Database' => '',
    'Date/Time' => 'Data/Hora',
    'Default Gateway' => 'Gateway Padrão',
    'Delete' => 'Apague',
    'Delete Account' => 'Apague Conta',
    'Delete Account Data' => 'Apague Dados de Conta',
    'Disable Account' => 'Desative Conta',
    'Disabled' => 'Desativado',
    'Disconnected' => 'Desligado',
    'Distribution of unique users over the VPN applications.' => 'Distribuição de utilizadores únicos pelas aplicações VPN',
    'Download' => 'Descarregar',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Não é permitido descarregar configurações VPN. Por favor utilize a aplicação VPN',
    //'Driver' => '',
    'Enable Account' => 'Ative Conta',
    'Error' => 'Erro',
    'Excluded Route(s)' => 'Rota(s) Excluída(s)',
    'Expires On' => 'Expira em',
    'Export (CSV)' => 'Exporte (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Encontre o identificador do utilizador que usou um endereço IPv4 ou IPv6 num determinado momento.',
    'Fingerprint' => 'Impressão Digital',
    'Here you can change the password for your account.' => 'Aqui pode mudar a palavra-passe da sua conta.',
    'Home' => 'Início',
    'Hostname' => 'Nome de Host',
    'IP Address' => 'Endereço IP',
    'IPs' => 'IPs',
    'IPv4 Prefix' => 'Prefixo IPv4',
    'IPv6 Prefix' => 'Prefixo IPv6',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importe ou copie/cole esta configuração para a sua aplicação WireGuard',
    'Info' => 'Informações',
    'Issues' => 'Problemas',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'Direto',
    'Log' => 'Log',
    //'MTU' => '',
    //'Maintenance' => '',
    'Max #Connections' => '# Máximo de Ligações',
    'More' => 'Mais',
    'N/A' => 'N/A',
    'Name' => 'Nome',
    'New Configuration' => 'Nova Configuração',
    'New Password' => 'Nova Palavra-passe',
    'New Password (confirm)' => 'Nova Palavra-passe (confirme)',
    'New Password and New Password (confirm) MUST match!' => 'Nova Palavra-passe e Nova Palavra-passe (confirme) TÊM de ser iguais!',
    'No Permission(s)' => 'Sem Acesso(s)',
    'No VPN profiles are available for your account.' => 'Não existem perfis VPN disponíveis para a sua conta.',
    'Node URL' => 'Nó de URL',
    'Node(s)' => 'Nó(s)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Obtenha um novo ficheiro de configuração VPN para utilização no seu cliente de VPN.',
    'Offered Ports' => 'Portas Disponíveis',
    'Offline' => 'Desligado',
    'Online' => 'Online',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Aprove apenas se estiver a tentar estabelecer uma ligação VPN com esta aplicação.',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'Registo de OpenVPN no Servidor',
    'Password' => 'Palavra-passe',
    'Permissions' => 'Acessos',
    'Please sign in with your username and password.' => 'Por favor autentique-se com o seu nome de utilizador e palavra-passe.',
    'Port' => 'Porta',
    'Ports' => 'Portas',
    'Preferred Protocol' => 'Protocolo Preferido',
    'Profile' => 'Perfil',
    //'Profile ID' => '',
    'Profile Usage' => 'Utilização de Perfil',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Perfil(is)',
    //'Proxy URL' => '',
    'Public Key' => 'Chave Pública',
    //'Refresh' => '',
    'Results' => 'Resultados',
    'Revoke' => 'Revogar',
    'Route(s)' => 'Rota(s)',
    'Search' => 'Procurar',
    'Select a profile and choose a name, e.g. "Phone".' => 'Selecione um perfil e escolha um nome, como, por exemplo, "Telemóvel".',
    'Server' => 'Servidor',
    'Sign In' => 'Entrar',
    'Sign Out' => 'Sair',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Estatísticas',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => 'A <em>Data/Hora</em>    tem de ser em UTC',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'O campo <em>Data/Hora</em> aceita datas com o formato <code>Y-m-d H:m:s</code>, p.ex. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'As credenciais que forneceu não estavam corretas',
    'The list of applications you authorized to create a VPN connection.' => 'A lista de aplicações que autorizou a criar ligações VPN.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'O número máximo de clientes VPN ligados simultaneamente num determinado momento durante a semana passada',
    'The most recent VPN connections with this account.' => 'As ligações VPN mais recentes com esta conta.',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => 'O número de utilizadores únicos ligados ao serviço VPN na semana passada',
    'The table below shows the per profile VPN usage over the last week.' => 'A tabela abaixo mostra a utilização de VPN por perfil durante a semana passada',
    'There are no results matching your criteria.' => 'Não há resultados que satisfaçam os seus critérios',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Este servidor usa uma fonte de autenticação externa. Apagar os dados de conta não impede que o utilizador se autentique (novamente)!',
    'This user does not have any active configurations.' => 'Este utilizador não tem nenhumas configurações ativas.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Este utilizador não tem nenhumas ligações.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Para impedir que aplicações maliciosas estabeleçam secretamente uma ligação VPN em seu nome, tem de aprovar explicitamente esta aplicação.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Use a aplicação WireGuard no seu dispositivo móvel para ler este código QR',
    'User ID' => 'ID de Utilizador',
    'Username' => 'Nome de Utilizador',
    'Users' => 'Utilizadores',
    'VPN Portal' => 'Portal VPN',
    'Version' => 'Versão',
    'Welcome to this VPN service!' => 'Bem-vindo a este serviço VPN!',
    'Why is this necessary?' => 'Porque que é que isto é necessário?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'Configuração de WireGuard',
    'You can download the detailed VPN usage statistics below.' => 'Pode descarregar as estatísticas detalhadas de utilização da VPN abaixo.',
    'You cannot manage your own user account.' => 'Não pode gerir a sua própria conta de utilizador.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Atingiu o número máximo de configurações de VPN ativas permitidas. Apague algumas primeiro.',
    'Your account does not have access to any VPN profile.' => 'A sua conta não tem acesso a nenhum perfil de VPN.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'A sua nova configuração expira em %expiryDate%. Volte aqui para criar uma nova configuração após esta expirar!',
];
